<?php
if( ! class_exists( 'WP_List_Table' ) ) {
    require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}

/**
 * Ads_Table_WPTO class.
 *
 * @extends WP_List_Table
 */
class Ads_Table_WPTO extends WP_List_Table {

	/**
	 * example_data
	 *
	 * (default value: array())
	 *
	 * @var array
	 * @access public
	 */
	var $example_data = array();

	/**
	 * __construct function.
	 *
	 * @access public
	 * @return void
	 */
	function __construct(){
        parent::__construct();
    }

	/**
	 * set_data function.
	 *
	 * @access public
	 * @param array $datas (default: array())
	 * @return void
	 */
	function set_data( $datas=array() ) {
		$this->example_data = $datas;
	}

	/**
	 * no_items function.
	 *
	 * @access public
	 * @return void
	 */
	function no_items() {
		_e( 'No ad found.' );
	}

	/**
	 * column_default function.
	 *
	 * @access public
	 * @param mixed $item
	 * @param mixed $column_name
	 * @return void
	 */
	function column_default( $item, $column_name ) {
		switch( $column_name ) {
			case 'ad_name':
				return $item[ $column_name ];
			case 'ad_group':
				return $item[ $column_name ];
			case 'start_date':

				// If start date is after current time make date red

				if (strtotime(current_time('mysql')) < strtotime($item[$column_name])) {
					return '<span style="color:red;">' . date('m/d/Y g:i A', strtotime($item[$column_name])) . '</span>';
				} else {
					return date('m/d/Y g:i A', strtotime($item[$column_name]));
				}

			case 'end_date':

				// If start date is after current time make date red

				if (strtotime(current_time('mysql')) > strtotime($item[$column_name])) {
					return '<span style="color:red;">' . date('m/d/Y g:i A', strtotime($item[$column_name])) . '</span>';
				} else {
					return date('m/d/Y g:i A', strtotime($item[$column_name]));
				}
			case 'priority':
				return $item[ $column_name ];
			case 'active_fg':

				if ($item[$column_name] == 'Active') {
					return '<span style="color:green;"><span class="glyphicon glyphicon-ok"></span> ON</span>';
				} else {
					return '<span style="color:red;"><span class="glyphicon glyphicon-minus"></span> OFF</span>';
				}

			default:
				return $item[$column_name];
		}
	}

	/**
	 * get_sortable_columns function.
	 *
	 * @access public
	 * @return void
	 */
	function get_sortable_columns() {
		$sortable_columns = array(
			'ad_name'  		=> array('ad_name',false),
			'ad_group' 		=> array('ad_group',false),
			'start_date' 	=> array('start_date',false),
			'end_date' 		=> array('end_date',false),
			'priority' 		=> array('priority',false),
			'active_fg'  	=> array('active_fg',false)
		);
		//return $sortable_columns;
		return null;
	}

	/**
	 * get_columns function.
	 *
	 * @access public
	 * @return void
	 */
	function get_columns(){
		$columns = array(
			//'cb'   => '<input type="checkbox" />',
			'active_fg'          => __( 'Status', WPsite_Wallpaper_Takeover:: $text_domain),
			'ad_name'            => __( 'Name', WPsite_Wallpaper_Takeover:: $text_domain),
			'ad_group'           => __( 'Group', WPsite_Wallpaper_Takeover:: $text_domain),
			'impressions'        => __( 'Impressions', WPsite_Wallpaper_Takeover::$text_domain),
			//'left_clicks'        => __( 'Left Clicks', WPsite_Wallpaper_Takeover::$text_domain),
			//right_clicks'       => __( 'Right Clicks', WPsite_Wallpaper_Takeover::$text_domain),
			'click_through_rate' => __( 'Click-Through Rate', WPsite_Wallpaper_Takeover::$text_domain),
			'start_date'         => __( 'Start date', WPsite_Wallpaper_Takeover:: $text_domain),
			'end_date'           => __( 'End date', WPsite_Wallpaper_Takeover:: $text_domain),
			//'priority'           => __( 'Priority', WPsite_Wallpaper_Takeover:: $text_domain),
		);
		return $columns;
	}

	/**
	 * usort_reorder function.
	 *
	 * @access public
	 * @param mixed $a
	 * @param mixed $b
	 * @return void
	 */
	function usort_reorder( $a, $b ) {
		// If no sort, default to title
		$orderby = ( ! empty( $_GET['orderby'] ) ) ? $_GET['orderby'] : 'ad_name';
		// If no order, default to asc
		$order = ( ! empty($_GET['order'] ) ) ? $_GET['order'] : 'asc';
		// Determine sort order
		$result = strcmp( $a[$orderby], $b[$orderby] );
		// Send final sort direction to usort
		return ( $order === 'asc' ) ? $result : -$result;
	}

	/**
	 * Adds row actions to the Name column
	 *
	 * @access public
	 * @param mixed $item
	 * @return void
	 */
	function column_ad_name($item) {

		$actions = array(
			'edit_1'	=> sprintf('<a class="btn btn-primary btn-xs" href="?page=new-ad-wpto&ad_id=%s">Edit</a>', isset($item['ad_id']) ? $item['ad_id'] : ''),
			'edit_2' 	=> sprintf('<a class="btn btn-danger btn-xs delete_btn" data-toggle="modal" data-target="#myModal" href="#" data-id="%s" data-url="?page=ad-control-wpto&action=%s&ad_id=%s&ad_name=%s">Delete</a>', isset($item['ad_name']) ? $item['ad_name'] : '', 'delete', isset($item['ad_id']) ? $item['ad_id'] : '', $item['ad_name'])
		);

		$name = $item['ad_name'];

		return sprintf('%1$s %2$s', $name, $this->row_actions($actions) );
	}

	/**
	 * Adds row actions to the Status column
	 *
	 * @access public
	 * @param mixed $item
	 * @return void
	 */
	function column_active_fg($item) {

		if($item['active_fg'] == "Active") {

			$actions = array(
				'inactive'	=> sprintf('<a class="btn btn-danger btn-xs" href="?page=ad-control-wpto&set_action=%s&ad_id=%s"><span style="color:white;" class="glyphicon glyphicon-off"></a>', 'inactivate', isset($item['ad_id']) ? $item['ad_id'] : '')
			);

		}

		if($item['active_fg'] == "Inactive") {

			$actions = array(
				'inactive'	=> sprintf('<a class="btn btn-success btn-xs" href="?page=ad-control-wpto&set_action=%s&ad_id=%s"><span style="color:white;" class="glyphicon glyphicon-off"></a>', 'activate', isset($item['ad_id']) ? $item['ad_id'] : '')
			);

		}

		if ($item['active_fg'] == 'Active') {
			$item = '<span style="color:green;"><span class="glyphicon glyphicon-ok"></span> ON</span>';
		} else {
			$item = '<span style="color:red;"><span class="glyphicon glyphicon-minus"></span> OFF</span>';
		}

		return sprintf('%1$s %2$s', $item, $this->row_actions($actions) );
	}

	/**
	 * column_cb function.
	 *
	 * @access public
	 * @param mixed $item
	 * @return void
	 */
	function column_cb($item) {
		return sprintf(
			'<input type="checkbox" name="ad_ids[]" value="%s" />', $item['ad_id']
		);
	}

	/**
	 * Custom function for the impressions column
	 *
	 * @since 1.0.0
	 *
	 * @param	array $item A singular item (one full row's worth of data)
	 * @return	string Text to be placed inside the column <td> (movie title only)
	 */
	function column_impressions($item) {

		$stats = WPsite_Stats_BT::getStats(null, null, $item['ad_id']);

		$impressions_total = 0;
		foreach ($stats as $stat) {
		    $impressions_total += $stat['impressions'];
		}

		return $impressions_total;
	}

	/**
	 * Custom function for the left clicks column
	 *
	 * @since 1.0.0
	 *
	 * @param	array $item A singular item (one full row's worth of data)
	 * @return	string Text to be placed inside the column <td> (movie title only)
	 */
	function column_left_clicks($item) {

		$stats = WPsite_Stats_BT::getStats(null, null, $item['ad_id']);

		$clicks_total = 0;
		foreach ($stats as $stat) {
		    $clicks_total += $stat['left_clicks'];
		}

		return $clicks_total;
	}

	/**
	 * Custom function for the left clicks column
	 *
	 * @since 1.0.0
	 *
	 * @param	array $item A singular item (one full row's worth of data)
	 * @return	string Text to be placed inside the column <td> (movie title only)
	 */
	function column_right_clicks($item) {

		$stats = WPsite_Stats_BT::getStats(null, null, $item['ad_id']);

		$clicks_total = 0;
		foreach ($stats as $stat) {
		    $clicks_total += $stat['right_clicks'];
		}

		return $clicks_total;
	}

	/**
	 * Custom function for the clicks column
	 *
	 * @since 1.0.0
	 *
	 * @param	array $item A singular item (one full row's worth of data)
	 * @return	string Text to be placed inside the column <td> (movie title only)
	 */
	function column_click_through_rate($item) {

		$stats = WPsite_Stats_BT::getStats(null, null, $item['ad_id']);

		$impressions_total = 0;
		$clicks_total = 0;
		foreach ($stats as $stat) {
		    $clicks_total += $stat['left_clicks'];
		    $clicks_total += $stat['right_clicks'];
		    $impressions_total += $stat['impressions'];
		}

		//Build row actions
        $actions = array(
            'edit'      => sprintf('<a href="?page=%s&background_takeover_id=%s&background_takeover_name=%s" class="btn btn-primary btn-xs">%s</a>',
            	WPsite_Wallpaper_Takeover::$stats_page,
            	$item['ad_id'],
            	$item['ad_name'],
            	__("Stats", WPsite_Wallpaper_Takeover::$text_domain)),
        );

        $ctr = $impressions_total != 0 ? round(($clicks_total/$impressions_total) * 100, 2) : 0;

        //Return the title contents
        return sprintf('%1$s %2$s',
            $ctr . '%',
            $this->row_actions($actions)
        );
	}

	/**
	 * Get a list of CSS classes for the <table> tag
	 *
	 * @since 3.1.0
	 * @access protected
	 *
	 * @return array
	 */
	public function get_table_classes() {
	    return array('table table-striped table-responsive');
	}

	/**
	 * prepare_items function.
	 *
	 * @access public
	 * @return void
	 */
	function prepare_items() {
		$columns  = $this->get_columns();
		$hidden   = array();
		$sortable = $this->get_sortable_columns();
		$this->_column_headers = array( $columns, $hidden, $sortable );

		if (isset($this->example_data) && $this->example_data)
			usort( $this->example_data, array( &$this, 'usort_reorder' ) );

		$per_page = 10;
		$current_page = $this->get_pagenum();

		if (isset($this->example_data) && $this->example_data) {
			$total_items = count( $this->example_data );
		}

		if (isset($this->example_data) && $this->example_data) {
			$this->example_data = array_slice( $this->example_data,( ( $current_page-1 )* $per_page ), $per_page );
		}

		$this->set_pagination_args(array(
			'total_items' => isset($total_items) ? $total_items : 0,                  //WE have to calculate the total number of items
			'per_page'    => $per_page                     //WE have to determine how many items to show on a page
		));

		$this->items = isset($this->example_data) ? $this->example_data : null;
	}

	/**
	 * Display the table
	 *
	 * @since 3.1.0
	 * @access public
	 */
	public function display() {
		$singular = $this->_args['singular'];

		$this->display_tablenav( 'top' );

		?>
		<table class="<?php echo implode( ' ', $this->get_table_classes() ); ?>">
			<thead>
			<tr>
				<?php $this->print_column_headers(); ?>
			</tr>
			</thead>

<!--
			<tfoot>
			<tr>
				<?php $this->print_column_headers( false ); ?>
			</tr>
			</tfoot>
-->

			<tbody id="the-list"<?php
				if ( $singular ) {
					echo " data-wp-lists='list:$singular'";
				} ?>>
				<?php $this->display_rows_or_placeholder(); ?>
			</tbody>
		</table>
		<?php
		$this->display_tablenav( 'bottom' );
	}

	/**
	 * Generate row actions div
	 *
	 * @since 3.1.0
	 * @access protected
	 *
	 * @param array $actions The list of actions
	 * @param bool $always_visible Whether the actions should be always visible
	 * @return string
	 */
	protected function row_actions( $actions, $always_visible = false ) {

		$action_count = count( $actions );
		$i = 0;

		if ( !$action_count )
			return '';

		$out = '<div class="' . ( $always_visible ? 'row-actions visible' : 'row-actions' ) . '">';
		foreach ( $actions as $action => $link ) {
			++$i;
			( $i == $action_count ) ? $sep = '' : $sep = ' | ';
			$out .= "<span class='$action'>$link$sep</span>";
		}
		$out .= '</div>';

		return $out;
	}

	/**
	 * Generates and display row actions links for the list table.
	 *
	 * @since 4.3.0
	 * @access protected
	 *
	 * @param object $item        The item being acted upon.
	 * @param string $column_name Current column name.
	 * @param string $primary     Primary column name.
	 * @return string The row actions output. In this case, an empty string.
	 */
	protected function handle_row_actions( $item, $column_name, $primary ) {
		return '';
 	}

} //class
?>